@@ -203,7 +203,6 @@ class BaseTestOptions(OptionParser):
 
     def __init__(self, *args, **kwargs):
         super(BaseTestOptions, self).__init__(*args, **kwargs)
-        self['tests'] = set()
 
     def opt_help_runners(self):
         """List the runners which are supported."""
@@ -239,11 +238,12 @@ class BaseTestOptions(OptionParser):
         self['test'] = option
 
     # We use some camelcase names for trial compatibility here.
-    # pylint: disable=C0103
     def parseArgs(self, *args):
         """Handle the extra arguments."""
-        self['tests'].update(args)
-    # pylint: enable=C0103
+        if isinstance(self.tests, set):
+            self['tests'].update(args)
+        elif isinstance(self.tests, list):
+            self['tests'].extend(args)
 
 
 def _get_runner_options(runner_name):
