@@ -34,10 +34,8 @@ import os
 
 from twisted.internet import defer
 
-# lint seems not tow work well when we use decorators
-# pylint:disable=W0611
-from ubuntuone.devtools.testcase import BaseTestCase, skipIf
-# pylint:enable=W0611
+from ubuntuone.devtools.testcases import BaseTestCase, skipIf
+
 # DBusRunner for DBusTestCase using tests
 from ubuntuone.devtools.services.dbus import DBusRunner
 
@@ -73,7 +71,7 @@ class FakeDBusInterface(object):
 
 
 @skipIf(dbus is None or service is None or DBusGMainLoop is None,
-    "The test requires dbus.")
+        "The test requires dbus.")
 class DBusTestCase(BaseTestCase):
     """Test the DBus event handling."""
 
@@ -112,7 +110,7 @@ class DBusTestCase(BaseTestCase):
         # str instead of anything from ubuntuone.devtools.compat. dbus
         # expects this to be str regardless of version.
         self.bus = dbus.bus.BusConnection(address_or_type=str(bus_address),
-                    mainloop=self.loop)
+                                          mainloop=self.loop)
 
         # Monkeypatch the dbus.SessionBus/SystemBus methods, to ensure we
         # always point at our own private bus instance.
