@@ -28,7 +28,7 @@
 # files in the program, then also delete it here.
 """Base squid tests cases and test utilities."""
 
-from ubuntuone.devtools.testcase import BaseTestCase, skipIf
+from ubuntuone.devtools.testcases import BaseTestCase, skipIf
 from ubuntuone.devtools.services.squid import (
     SquidRunner,
     SquidLaunchError,
