@@ -143,7 +143,7 @@ class TidySocketServer(object):
         self.server_factory = tidy_class(*args, **kwargs)
         self.server_factory._disconnecting = False
         self.server_factory.protocol = server_protocol_factory(
-                                                 self.server_factory.protocol)
+            self.server_factory.protocol)
         endpoint = endpoints.serverFromString(reactor,
                                               self.get_server_endpoint())
         self.listener = yield endpoint.listen(self.server_factory)
@@ -163,10 +163,10 @@ class TidySocketServer(object):
         self.client_factory = client_class(*args, **kwargs)
         self.client_factory._disconnecting = False
         self.client_factory.protocol = client_protocol_factory(
-                                                 self.client_factory.protocol)
+            self.client_factory.protocol)
         self.client_factory.testserver_on_connection_lost = defer.Deferred()
         endpoint = endpoints.clientFromString(reactor,
-                                                    self.get_client_endpoint())
+                                              self.get_client_endpoint())
         self.connector = yield endpoint.connect(self.client_factory)
         defer.returnValue(self.client_factory)
 
@@ -183,12 +183,14 @@ class TidySocketServer(object):
             d = defer.maybeDeferred(self.listener.stopListening)
             self.connector.transport.loseConnection()
             if self.server_factory.testserver_on_connection_lost:
-                return defer.gatherResults([d,
-                    self.client_factory.testserver_on_connection_lost,
-                    self.server_factory.testserver_on_connection_lost])
+                return defer.gatherResults(
+                    [d,
+                     self.client_factory.testserver_on_connection_lost,
+                     self.server_factory.testserver_on_connection_lost])
             else:
-                return defer.gatherResults([d,
-                    self.client_factory.testserver_on_connection_lost])
+                return defer.gatherResults(
+                    [d,
+                     self.client_factory.testserver_on_connection_lost])
         if self.listener:
             # just clean the server since there is no client
             # pylint: disable=W0201
@@ -213,7 +215,7 @@ class TidyTCPServer(TidySocketServer):
             raise ValueError('Server Factory was not provided.')
         if self.listener is None:
             raise ValueError('%s has not started listening.',
-                                                          self.server_factory)
+                             self.server_factory)
         return self.client_endpoint_pattern % self.listener.getHost().port
 
 
@@ -279,9 +281,9 @@ class ServerTestCase(BaseTestCase):
         passed to the server constructor.
         """
         self.server_factory = yield self.server_runner.listen_server(
-                                                server_class, *args, **kwargs)
+            server_class, *args, **kwargs)
         self.server_disconnected = \
-                self.server_factory.testserver_on_connection_lost
+            self.server_factory.testserver_on_connection_lost
         self.listener = self.server_runner.listener
 
     @defer.inlineCallbacks
@@ -292,9 +294,9 @@ class ServerTestCase(BaseTestCase):
         should be passed to the client constructor.
         """
         self.client_factory = yield self.server_runner.connect_client(
-                                                client_class, *args, **kwargs)
+            client_class, *args, **kwargs)
         self.client_disconnected = \
-                self.client_factory.testserver_on_connection_lost
+            self.client_factory.testserver_on_connection_lost
         self.connector = self.server_runner.connector
 
     def tear_down_server_client(self):
@@ -330,13 +332,13 @@ class PbServerTestCase(ServerTestCase):
     def listen_server(self, *args, **kwargs):
         """Listen a pb server."""
         yield super(PbServerTestCase, self).listen_server(pb.PBServerFactory,
-                                                              *args, **kwargs)
+                                                          *args, **kwargs)
 
     @defer.inlineCallbacks
     def connect_client(self, *args, **kwargs):
         """Connect a pb client."""
         yield super(PbServerTestCase, self).connect_client(pb.PBClientFactory,
-                                                              *args, **kwargs)
+                                                           *args, **kwargs)
 
 
 class TCPPbServerTestCase(PbServerTestCase):
